<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=ay
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Yatqallta askichaña',
];
